@@ -151,6 +151,8 @@ class Build(HeadersMixin):
     build_name = attrib(default=None)
     status = attrib(default={})
     uid = attrib(default=None)
+    json = attrib(default=False)
+    limit = attrib(default=0)
 
     def __attrs_post_init__(self):
         if isinstance(self.kconfig, str):
@@ -583,9 +585,16 @@ class Plan(HeadersMixin):
                             group=self.group,
                             project=self.project,
                             device=test["device"],
-                            kernel=test["kernel"],
+                            kernel=test.get("kernel"),
+                            mcp_fw=test.get("mcp_fw"),
+                            mcp_romfw=test.get("mcp_romfw"),
                             modules=test.get("modules"),
+                            parameters=test.get("parameters", {}),
+                            rootfs=test.get("rootfs"),
+                            scp_fw=test.get("scp_fw"),
+                            scp_romfw=test.get("scp_romfw"),
                             tests=test.get("tests", []),
+                            uefi=test.get("uefi"),
                             boot_args=test.get("boot_args"),
                         )
                     )
@@ -777,7 +786,14 @@ class Test(HeadersMixin):
     project = attrib()
     device = attrib()
     kernel = attrib(default=None)
+    mcp_fw = attrib(default=None)
+    mcp_romfw = attrib(default=None)
     modules = attrib(default=None)
+    parameters = attrib(default=[])
+    rootfs = attrib(default=None)
+    scp_fw = attrib(default=None)
+    scp_romfw = attrib(default=None)
+    uefi = attrib(default=None)
     tests = attrib(default=[])
     boot_args = attrib(default=None)
     wait_for = attrib(default=None)
@@ -793,7 +809,17 @@ class Test(HeadersMixin):
         return "{} {} @ {}".format(tests, self.device, self.url)
 
     def generate_test_request(self, plan=None):
-        data = {"device": self.device, "kernel": self.kernel}
+        data = {
+            "device": self.device,
+            "kernel": self.kernel,
+            "mcp_fw": self.mcp_fw,
+            "mcp_romfw": self.mcp_romfw,
+            "parameters": self.parameters,
+            "rootfs": self.rootfs,
+            "scp_fw": self.scp_fw,
+            "scp_romfw": self.scp_romfw,
+            "uefi": self.uefi,
+        }
         if self.modules:
             data["modules"] = self.modules
         if self.tests:
